@@ -2,7 +2,7 @@ struct Application;
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        wita::WindowBuilder::new()
+        wita::Window::builder()
             .style(wita::WindowStyle::borderless())
             .build()?;
         Ok(Self)
