@@ -2,7 +2,7 @@ struct Application;
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        wita::WindowBuilder::new().title("wita events").build()?;
+        wita::Window::builder().title("wita events").build()?;
         Ok(Self)
     }
 }
