@@ -4,7 +4,7 @@ struct Application {
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        wita::WindowBuilder::new()
+        wita::Window::builder()
             .title("wita no redirection bitmap")
             .no_redirection_bitmap(true)
             .build()?;
