@@ -2,7 +2,7 @@ struct Application;
 
 impl Application {
     fn new() -> anyhow::Result<Self> {
-        wita::WindowBuilder::new()
+        wita::Window::builder()
             .title("wita window params")
             .position((100, 100))
             .build()?;
