@@ -1,11 +1,6 @@
-use windows::Win32::{
-    Foundation::*,
-    Graphics::Gdi::*,
-    UI::HiDpi::*,
-    UI::WindowsAndMessaging::*,
-};
 use crate::geometry::*;
 use std::sync::Once;
+use windows::Win32::{Foundation::*, Graphics::Gdi::*, UI::HiDpi::*, UI::WindowsAndMessaging::*};
 
 pub fn get_dpi_from_point(pt: ScreenPosition) -> u32 {
     unsafe {
@@ -22,7 +17,12 @@ pub fn get_dpi_from_point(pt: ScreenPosition) -> u32 {
     }
 }
 
-pub fn adjust_window_rect(size: PhysicalSize<u32>, style: u32, ex_style: u32, dpi: u32) -> RECT {
+pub fn adjust_window_rect(
+    size: PhysicalSize<u32>,
+    style: WINDOW_STYLE,
+    ex_style: WINDOW_EX_STYLE,
+    dpi: u32,
+) -> RECT {
     unsafe {
         let mut rc = RECT {
             left: 0,
@@ -53,3 +53,17 @@ pub fn enable_gui_thread() {
         IsGUIThread(true);
     }
 }
+
+pub fn child_windows(hwnd: HWND) -> Vec<HWND> {
+    unsafe extern "system" fn callback(hwnd: HWND, lparam: LPARAM) -> BOOL {
+        let v = (lparam.0 as *mut Vec<HWND>).as_mut().unwrap();
+        v.push(hwnd);
+        true.into()
+    }
+
+    unsafe {
+        let mut v = Vec::new();
+        EnumChildWindows(hwnd, Some(callback), LPARAM(&mut v as *mut Vec<HWND> as _));
+        v
+    }
+}
