@@ -1,11 +1,7 @@
-use windows::Win32::{
-    Foundation::*,
-    UI::Input::KeyboardAndMouse::*,
-    UI::WindowsAndMessaging::*,
-};
 use crate::geometry::*;
 #[cfg(feature = "serde")]
 use serde::{de::*, *};
+use windows::Win32::{Foundation::*, UI::Input::KeyboardAndMouse::*, UI::WindowsAndMessaging::*};
 
 /// Describes the state of a keyboard key and a mouse button.
 #[derive(Clone, Copy, PartialEq, Eq, Debug, Hash)]
@@ -203,11 +199,14 @@ impl KeyCode {
     }
 }
 
-pub fn as_virtual_key(k: u32) -> VirtualKey {
+pub fn as_virtual_key(k: VIRTUAL_KEY) -> VirtualKey {
     const ZERO: u16 = b'0' as _;
     const Z: u16 = b'Z' as _;
-    match k as u16 {
-        v @ ZERO..=Z => VirtualKey::Char((v as u8).into()),
+    const NUMPAD0: u16 = VK_NUMPAD0.0;
+    const NUMPAD9: u16 = VK_NUMPAD9.0;
+    const F1: u16 = VK_F1.0;
+    const F24: u16 = VK_F24.0;
+    match k {
         VK_ESCAPE => VirtualKey::Esc,
         VK_TAB => VirtualKey::Tab,
         VK_CAPITAL => VirtualKey::CapsLock,
@@ -231,7 +230,6 @@ pub fn as_virtual_key(k: u32) -> VirtualKey {
         VK_LEFT => VirtualKey::Left,
         VK_RIGHT => VirtualKey::Right,
         VK_NUMLOCK => VirtualKey::NumLock,
-        v @ VK_NUMPAD0..=VK_NUMPAD9 => VirtualKey::NumPad((v - VK_NUMPAD0) as u8),
         VK_ADD => VirtualKey::NumAdd,
         VK_SUBTRACT => VirtualKey::NumSub,
         VK_MULTIPLY => VirtualKey::NumMul,
@@ -255,18 +253,22 @@ pub fn as_virtual_key(k: u32) -> VirtualKey {
         VK_OEM_6 => VirtualKey::Char(']'),
         VK_OEM_7 => VirtualKey::Char('^'),
         VK_OEM_102 => VirtualKey::Char('_'),
-        v @ VK_F1..=VK_F24 => VirtualKey::F((v - VK_F1 + 1) as u8),
-        v => VirtualKey::Other(v as u32),
+        v => match v.0 {
+            w @ ZERO..=Z => VirtualKey::Char((w as u8).into()),
+            w @ NUMPAD0..=NUMPAD9 => VirtualKey::NumPad((w - NUMPAD0) as u8),
+            w @ F1..=F24 => VirtualKey::F((w - F1 + 1) as u8),
+            w => VirtualKey::Other(w as u32),
+        },
     }
 }
 
-pub fn to_raw_virtual_key(k: VirtualKey) -> u32 {
+pub fn to_raw_virtual_key(k: VirtualKey) -> VIRTUAL_KEY {
     const ZERO: char = '0' as _;
     const Z: char = 'Z' as _;
     match k {
-        VirtualKey::Char(c) if (ZERO..=Z).contains(&c) => return c as u32,
-        VirtualKey::NumPad(n) => return VK_NUMPAD0 as u32 + n as u32,
-        VirtualKey::F(n) => return VK_F1 as u32 + n as u32 - 1,
+        VirtualKey::Char(c) if (ZERO..=Z).contains(&c) => return VIRTUAL_KEY(c as u16),
+        VirtualKey::NumPad(n) => return VIRTUAL_KEY(VK_NUMPAD0.0 + n as u16),
+        VirtualKey::F(n) => return VIRTUAL_KEY(VK_F1.0 + n as u16 - 1),
         _ => {}
     }
     match k {
@@ -317,14 +319,14 @@ pub fn to_raw_virtual_key(k: VirtualKey) -> u32 {
         VirtualKey::Char('^') => VK_OEM_7,
         VirtualKey::Char('_') => VK_OEM_102,
         _ => match k {
-            VirtualKey::Other(x) => return x,
+            VirtualKey::Other(x) => return VIRTUAL_KEY(x as u16),
             _ => unreachable!(),
-        }
-    }.into()
+        },
+    }
 }
 
 pub fn get_key_state(k: VirtualKey) -> bool {
-    unsafe { GetKeyState(to_raw_virtual_key(k) as _) & 0x80 != 0 }
+    unsafe { GetKeyState(to_raw_virtual_key(k).0 as _) & 0x80 != 0 }
 }
 
 /// Get current key states.
@@ -336,7 +338,7 @@ pub fn keyboard_state(keys: &mut Vec<VirtualKey>) {
     keys.clear();
     for (i, k) in buffer.iter().enumerate() {
         if (k & 0x80) != 0 {
-            keys.push(as_virtual_key(i as u32));
+            keys.push(as_virtual_key(VIRTUAL_KEY(i as _)));
         }
     }
 }
