@@ -1,8 +1,5 @@
-use windows::Win32::{
-    System::Diagnostics::Debug::*,
-    System::Memory::*,
-};
 use std::ptr::{null, null_mut};
+use windows::Win32::{System::Diagnostics::Debug::*, System::Memory::*};
 
 #[doc(hidden)]
 #[macro_export]
