@@ -1,11 +1,7 @@
 //! An IME composition string and a candidate list
 
-use windows::Win32::{
-    Foundation::*,
-    Globalization::*,
-    UI::Input::Ime::*,
-};
 use crate::geometry::*;
+use windows::Win32::{Foundation::*, Globalization::*, UI::Input::Ime::*};
 
 /// Describes composition character attributes.
 #[derive(Clone, Copy, PartialEq, Eq, Debug)]
