@@ -91,11 +91,8 @@ pub use monitor::*;
 pub use resource::*;
 pub use window::*;
 
-use windows::Win32::{
-    Foundation::*,
-    UI::WindowsAndMessaging::*,
-};
 use context::*;
+use windows::Win32::{Foundation::*, UI::WindowsAndMessaging::*};
 
 /// The value is an unit in logical coordinates.
 pub const DEFAULT_DPI: i32 = 96;
