@@ -1,18 +1,12 @@
-use windows::Win32::{
-    Foundation::*,
-    Graphics::Gdi::*,
-    UI::Controls::WM_MOUSELEAVE,
-    UI::HiDpi::*,
-    UI::Input::KeyboardAndMouse::*,
-    UI::Input::Ime::*,
-    UI::Shell::*,
-    UI::WindowsAndMessaging::*,
-};
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
 use crate::{api::*, context::*, device::*, event::EventHandler, geometry::*, ime, window::Window};
 use std::panic::catch_unwind;
 use std::path::PathBuf;
+use windows::Win32::{
+    Foundation::*, Graphics::Gdi::*, UI::Controls::WM_MOUSELEAVE, UI::HiDpi::*, UI::Input::Ime::*,
+    UI::Input::KeyboardAndMouse::*, UI::Shell::*, UI::WindowsAndMessaging::*,
+};
 
 #[derive(Clone, Copy, PartialEq, Eq, Debug)]
 #[repr(usize)]
@@ -123,7 +117,7 @@ fn key_input<T: EventHandler + 'static>(
     call_handler(|eh: &mut T, _| {
         eh.key_input(
             window,
-            KeyCode::new(as_virtual_key(wparam.0 as u32), scan_code),
+            KeyCode::new(as_virtual_key(VIRTUAL_KEY(wparam.0 as _)), scan_code),
             state,
             (lparam.0 >> 30) & 0x01 != 0,
         );
@@ -377,7 +371,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             }
             WM_WINDOWPOSCHANGED => {
                 let pos = &*(lparam.0 as *const WINDOWPOS);
-                if pos.flags & SWP_NOMOVE == 0 {
+                if pos.flags & SWP_NOMOVE == SET_WINDOW_POS_FLAGS(0) {
                     call_handler(|eh: &mut T, _| {
                         eh.moved(handle, ScreenPosition::new(pos.x, pos.y))
                     });
@@ -395,6 +389,8 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 DefWindowProcW(hwnd, msg, wparam, lparam)
             }
             WM_DPICHANGED => {
+                let mut prev_rc = RECT::default();
+                GetWindowRect(hwnd, &mut prev_rc);
                 let rc = *(lparam.0 as *const RECT);
                 SetWindowPos(
                     hwnd,
@@ -406,6 +402,51 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     SWP_NOZORDER | SWP_NOACTIVATE,
                 );
                 call_handler(|eh: &mut T, _| eh.dpi_changed(handle));
+                let prev_size = prev_rc.right - prev_rc.left;
+                let next_size = rc.right - rc.left;
+                let children = child_windows(hwnd);
+                for child in children {
+                    let child_rc = {
+                        let mut rc = RECT::default();
+                        let mut screen = RECT::default();
+                        GetWindowRect(child, &mut screen);
+                        let mut pt = POINT {
+                            x: screen.left,
+                            y: screen.top,
+                        };
+                        ScreenToClient(hwnd, &mut pt);
+                        rc.left = pt.x;
+                        rc.top = pt.y;
+                        let mut pt = POINT {
+                            x: screen.right,
+                            y: screen.bottom,
+                        };
+                        ScreenToClient(hwnd, &mut pt);
+                        rc.right = pt.x;
+                        rc.bottom = pt.y;
+                        rc
+                    };
+                    let pt = PhysicalPosition::new(
+                        child_rc.left * next_size / prev_size,
+                        child_rc.top * next_size / prev_size,
+                    );
+                    let size = PhysicalSize::new(
+                        (child_rc.right - child_rc.left) * next_size / prev_size,
+                        (child_rc.bottom - child_rc.top) * next_size / prev_size,
+                    );
+                    SetWindowPos(
+                        child,
+                        HWND(0),
+                        pt.x,
+                        pt.y,
+                        size.width,
+                        size.height,
+                        SWP_NOACTIVATE | SWP_NOZORDER,
+                    );
+                    if let Some(child) = find_window(child) {
+                        call_handler(|eh: &mut T, _| eh.dpi_changed(&child.handle));
+                    }
+                }
                 LRESULT(0)
             }
             WM_GETDPISCALEDSIZE => {
@@ -419,8 +460,8 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 );
                 let rc = adjust_window_rect(
                     size,
-                    GetWindowLongPtrW(hwnd, GWL_STYLE) as _,
-                    GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _,
+                    WINDOW_STYLE(GetWindowLongPtrW(hwnd, GWL_STYLE) as _),
+                    WINDOW_EX_STYLE(GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _),
                     next_dpi as u32,
                 );
                 let mut ret = (lparam.0 as *mut SIZE).as_mut().unwrap();
@@ -504,8 +545,8 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                         let state = handle.state.read().unwrap();
                         let rc = adjust_window_rect(
                             state.set_inner_size,
-                            GetWindowLongPtrW(hwnd, GWL_STYLE) as _,
-                            GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _,
+                            WINDOW_STYLE(GetWindowLongPtrW(hwnd, GWL_STYLE) as _),
+                            WINDOW_EX_STYLE(GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _),
                             GetDpiForWindow(hwnd),
                         );
                         SetWindowPos(
@@ -532,10 +573,10 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                         let rc = adjust_window_rect(
                             handle.inner_size().to_physical(handle.dpi()),
                             style,
-                            0,
+                            WINDOW_EX_STYLE(0),
                             GetDpiForWindow(hwnd),
                         );
-                        SetWindowLongPtrW(hwnd, GWL_STYLE, style as _);
+                        SetWindowLongPtrW(hwnd, GWL_STYLE, style.0 as _);
                         SetWindowPos(
                             hwnd,
                             HWND(0),
