@@ -2,13 +2,6 @@
 //!
 //! To use, specify `"raw_input"` feature.
 
-use windows::Win32::{
-    Foundation::*,
-    Devices::HumanInterfaceDevice::*,
-    Storage::FileSystem::*,
-    UI::Input::*,
-    UI::WindowsAndMessaging::*,
-};
 use crate::context::call_handler;
 use crate::device::*;
 use crate::last_error;
@@ -19,6 +12,10 @@ use std::cell::RefCell;
 use std::mem::size_of;
 use std::ptr::null_mut;
 use std::rc::Rc;
+use windows::Win32::{
+    Devices::HumanInterfaceDevice::*, Foundation::*, Storage::FileSystem::*,
+    UI::Input::KeyboardAndMouse::*, UI::Input::*, UI::WindowsAndMessaging::*,
+};
 
 const HID_USAGE_PAGE_GENERIC: u16 = 0x01;
 
@@ -99,11 +96,11 @@ unsafe fn get_device_interface(handle: HANDLE) -> Option<Vec<u16>> {
 unsafe fn get_device_name(interface: &[u16]) -> Option<String> {
     let handle = CreateFileW(
         PWSTR(interface.as_ptr() as _),
-        0,
+        FILE_ACCESS_FLAGS(0),
         FILE_SHARE_READ | FILE_SHARE_WRITE,
         null_mut(),
         OPEN_EXISTING,
-        0,
+        FILE_FLAGS_AND_ATTRIBUTES(0),
         HANDLE(0),
     );
     if handle == HANDLE(0) {
@@ -129,7 +126,7 @@ unsafe fn get_raw_input_device_info(handle: HANDLE) -> Option<RID_DEVICE_INFO> {
     let mut len = size_of::<RID_DEVICE_INFO>() as u32;
     let mut info = RID_DEVICE_INFO {
         cbSize: len as _,
-        dwType: 0,
+        dwType: RID_DEVICE_INFO_TYPE(0),
         Anonymous: RID_DEVICE_INFO_0 {
             keyboard: Default::default(),
         },
@@ -257,7 +254,8 @@ pub fn get_device_info(device: &Device) -> Option<DeviceInfo> {
                     let mut len = caps.NumberInputButtonCaps as u16;
                     let mut caps = Vec::with_capacity(len as _);
                     caps.set_len(len as _);
-                    if HidP_GetButtonCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p as _).is_err() {
+                    if HidP_GetButtonCaps(HidP_Input, caps.as_mut_ptr(), &mut len, p as _).is_err()
+                    {
                         last_error!("HidP_GetButtonCaps");
                         return None;
                     }
@@ -419,13 +417,14 @@ impl From<WPARAM> for WindowState {
 }
 
 pub(crate) fn register_devices(wnd: &Window, state: WindowState) {
-    let flags = {
-        RIDEV_DEVNOTIFY | if state == WindowState::Background {
-            RIDEV_INPUTSINK
-        } else {
-            0
-        }
-    };
+    let flags = RAWINPUTDEVICE_FLAGS(
+        RIDEV_DEVNOTIFY.0
+            | if state == WindowState::Background {
+                RIDEV_INPUTSINK.0
+            } else {
+                0
+            },
+    );
     let mut device = [
         RAWINPUTDEVICE {
             usUsagePage: HID_USAGE_PAGE_GENERIC,
@@ -622,7 +621,7 @@ pub enum InputData {
 unsafe fn input_data_keyboard(input: &mut RAWINPUT) -> Option<InputData> {
     let keyboard = input.data.keyboard;
     let code = KeyCode {
-        vkey: as_virtual_key(keyboard.VKey as _),
+        vkey: as_virtual_key(VIRTUAL_KEY(keyboard.VKey as _)),
         scan_code: ScanCode(keyboard.MakeCode as _),
     };
     let state = if (keyboard.Flags & (RI_KEY_BREAK as u16)) != 0 {
