@@ -1,8 +1,5 @@
-use windows::Win32::{
-    Foundation::*,
-    UI::WindowsAndMessaging::*,
-};
 use std::path::{Path, PathBuf};
+use windows::Win32::{Foundation::*, UI::WindowsAndMessaging::*};
 
 #[inline]
 fn make_int_resource(id: u16) -> PWSTR {
