@@ -1,11 +1,3 @@
-use windows::Win32::{
-    Foundation::*,
-    Graphics::Gdi::*,
-    System::LibraryLoader::*,
-    UI::HiDpi::*,
-    UI::Shell::*,
-    UI::WindowsAndMessaging::*,
-};
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
 use crate::DEFAULT_DPI;
@@ -20,10 +12,14 @@ use crate::{
     procedure::{window_proc, UserMessage},
     resource::*,
 };
-use raw_window_handle::{Win32Handle, HasRawWindowHandle, RawWindowHandle};
+use raw_window_handle::{HasRawWindowHandle, RawWindowHandle, Win32Handle};
 use std::cell::RefCell;
 use std::rc::Rc;
 use std::sync::{Arc, RwLock};
+use windows::Win32::{
+    Foundation::*, Graphics::Gdi::*, System::LibraryLoader::*, UI::HiDpi::*, UI::Shell::*,
+    UI::WindowsAndMessaging::*,
+};
 
 #[derive(Clone, PartialEq, Eq)]
 pub(crate) struct WindowHandle(HWND);
@@ -33,7 +29,7 @@ unsafe impl Sync for WindowHandle {}
 
 /// A window style and the borderless window style.
 pub trait Style {
-    fn value(&self) -> u32;
+    fn value(&self) -> WINDOW_STYLE;
 
     fn is_borderless(&self) -> bool {
         self.value() == WS_POPUP
@@ -44,13 +40,13 @@ pub trait Style {
 pub struct BorderlessStyle;
 
 impl Style for BorderlessStyle {
-    fn value(&self) -> u32 {
+    fn value(&self) -> WINDOW_STYLE {
         WS_POPUP
     }
 }
 
 /// Represents a window style.
-pub struct WindowStyle(u32);
+pub struct WindowStyle(WINDOW_STYLE);
 
 impl WindowStyle {
     #[inline]
@@ -114,7 +110,7 @@ impl Default for WindowStyle {
 }
 
 impl Style for WindowStyle {
-    fn value(&self) -> u32 {
+    fn value(&self) -> WINDOW_STYLE {
         self.0
     }
 }
@@ -153,7 +149,7 @@ pub struct WindowBuilder<Ti, S> {
     position: ScreenPosition,
     inner_size: S,
     visibility: bool,
-    style: u32,
+    style: WINDOW_STYLE,
     enabled_ime: bool,
     visible_ime_composition_window: bool,
     visible_ime_candidate_window: bool,
@@ -326,13 +322,13 @@ where
         unsafe {
             let dpi = get_dpi_from_point(self.position);
             let inner_size = self.inner_size.to_physical(dpi);
-            let rc = adjust_window_rect(inner_size, self.style, 0, dpi);
+            let rc = adjust_window_rect(inner_size, self.style, WINDOW_EX_STYLE(0), dpi);
             let hinst = GetModuleHandleW(PWSTR::default());
             let hwnd = CreateWindowExW(
                 if self.no_redirection_bitmap {
                     WS_EX_NOREDIRECTIONBITMAP
                 } else {
-                    0
+                    WINDOW_EX_STYLE(0)
                 },
                 WINDOW_CLASS_NAME,
                 self.title.as_ref(),
@@ -503,10 +499,10 @@ where
             let dpi = self.parent.dpi();
             let position = self.position.to_physical(dpi as i32);
             let size = self.size.to_physical(dpi);
-            let rc = adjust_window_rect(size, WS_CHILD, 0, dpi);
+            let rc = adjust_window_rect(size, WS_CHILD, WINDOW_EX_STYLE(0), dpi);
             let hinst = GetModuleHandleW(PWSTR::default());
             let hwnd = CreateWindowExW(
-                0,
+                WINDOW_EX_STYLE(0),
                 WINDOW_CLASS_NAME,
                 PWSTR::default(),
                 WS_CHILD,
@@ -555,7 +551,7 @@ where
 
 pub(crate) struct WindowState {
     pub title: String,
-    pub style: u32,
+    pub style: WINDOW_STYLE,
     pub set_position: (i32, i32),
     pub set_inner_size: PhysicalSize<u32>,
     pub enabled_ime: bool,
@@ -593,6 +589,16 @@ pub struct Window {
 }
 
 impl Window {
+    #[inline]
+    pub fn builder() -> WindowBuilder<&'static str, Size<u32, Logical>> {
+        WindowBuilder::new()
+    }
+
+    #[inline]
+    pub fn inner_builder() -> InnerWindowBuilder<(), LogicalPosition<f32>, ()> {
+        InnerWindowBuilder::new()
+    }
+
     pub fn title(&self) -> String {
         let state = self.state.read().unwrap();
         state.title.clone()
@@ -792,10 +798,8 @@ impl Eq for Window {}
 unsafe impl HasRawWindowHandle for Window {
     fn raw_window_handle(&self) -> RawWindowHandle {
         let mut handle = Win32Handle::empty();
-        handle.hinstance = unsafe {
-            GetModuleHandleW(PWSTR::default()).0 as *mut std::ffi::c_void
-        };
-        handle.hwnd = self.hwnd.0.0 as *mut std::ffi::c_void;
+        handle.hinstance = unsafe { GetModuleHandleW(PWSTR::default()).0 as *mut std::ffi::c_void };
+        handle.hwnd = self.hwnd.0 .0 as *mut std::ffi::c_void;
         RawWindowHandle::Win32(handle)
     }
 }
